@@ -5,6 +5,13 @@
 #include "argz.h"
 #include <stdio.h>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#if defined(HAVE_DMALLOC_H) && defined(DMALLOC)
+#include "dmalloc.h"
+#endif
+
 msg_t *msg_create(void)
 {
     msg_t *msg;
@@ -32,7 +39,7 @@ void msg_destroy(msg_t *msg)
 {
     if (msg == NULL)
         return;
-                                             //FIXME what about non-graceful aborts?
+                                             /*FIXME what about non-graceful aborts? */
     if (msg->azEnvgroups != NULL)
         free(msg->azEnvgroups);
     if (msg->cpMsg != NULL)
@@ -65,7 +72,7 @@ msg_rc_t msg_split(msg_t *msg)
     /* INPUTS
      *
      * msg->cpMsg
-     * must contain the wholly RFC822 formatted message with native
+     * must contain the wholly RFC0822 formatted message with native
      * (unescaped) dots at the beginning of a line, the 'From ' envelope,
      * headers, double newline, body, '\0', no trailing dot;
      *
@@ -91,7 +98,7 @@ msg_rc_t msg_split(msg_t *msg)
      */
 
     /* split message into header and body */
-    if (!str_parse(msg->cpMsg, "m/((?:.*?)\\n)\\n(.*)$/s", &cpHeaders, &msg->cpBody))
+    if (str_parse(msg->cpMsg, "m/((?:.*?)\\n)\\n(.*)$/s", &cpHeaders, &msg->cpBody) <= 0)
         return MSG_ERR_SPLITSPLITBODY;
 
     /* replace envelope From w/o colon by X-F: pseudotag. This eliminates the
@@ -103,18 +110,19 @@ msg_rc_t msg_split(msg_t *msg)
         memcpy(cpHeaders, "X-F:", 4);
 
     /* unwrap header lines */
-    //FIXME poor man's s///g simulator as current str library doesn't support //global substitution
-    while (str_parse(cpHeaders, "s/(.*?)\\n[ \\t]+(.*)/$1 $2/s", &cpRem)) {
+    /*FIXME poor man's s///g simulator as current str library doesn't support //global substitution */
+    while (str_parse(cpHeaders, "s/(.*?)\\n[ \\t]+(.*)/$1 $2/s", &cpRem) > 0) {
         free(cpHeaders);
         cpHeaders = cpRem;
     }
 
     /* split header lines into names and values */
-    //FIXME str enhancement requests and bugs to be fixed
-    //FIXME - fix bug "not" [^...] working
-    //FIXME - improve str_parse(foo, "...", &foo) should free foo() on it's own
-    //FIXME - add "global" in s/search/replace/g (see above "unwrap hader lines")
-    while (str_parse(cpHeaders, "m/^([\\w-]+?:)[ \\t]*(.*?)[ \\t]*\\n(.*)/s", &cpName, &cpValue, &cpRem)) {
+    /*FIXME str enhancement requests and bugs to be fixed */
+    /*FIXME - fix bug "not" [^...] working */
+    /*FIXME - improve str_parse(foo, "...", &foo) should free foo() on it's own */
+    /*FIXME - add "global" in s/search/replace/g (see above "unwrap hader lines") */
+    while (str_parse(cpHeaders, "m/^([\\w-]+?:)[ \\t]*(.*?)[ \\t]*\\n(.*)/s",
+                     &cpName, &cpValue, &cpRem) > 0) {
         free(cpHeaders);
         cpHeaders = cpRem;
         argz_add(&msg->azHeaders, &msg->asHeaders, cpName);
@@ -156,7 +164,7 @@ msg_rc_t msg_split(msg_t *msg)
             if (msg->cpMsgid != NULL)
                 return MSG_ERR_SPLITIDMULTI;
             argz_delete(&msg->azHeaders, &msg->asHeaders, cp);             /* del  name  */
-            //fprintf(stderr, "DEBUG: Message-ID cp = ***%s***\n", cp);
+            /*fprintf(stderr, "DEBUG: Message-ID cp = ***%s***\n", cp); */
             if ((cp == NULL) || (strlen(cp) == 0))                         /* get  value */
                 return MSG_ERR_SPLITIDEMPTY;
             if ((msg->cpMsgid = strdup(cp)) == NULL)
@@ -166,7 +174,7 @@ msg_rc_t msg_split(msg_t *msg)
         }
         if (strcasecmp("Newsgroups:", cp) == 0) {
             argz_delete(&msg->azHeaders, &msg->asHeaders, cp);             /* del  name  */
-            //fprintf(stderr, "DEBUG: Newsgroups cp = ***%s***\n", cp);
+            /*fprintf(stderr, "DEBUG: Newsgroups cp = ***%s***\n", cp); */
             if (argz_add(&msg->azNewsgroups, &msg->asNewsgroups, cp) != 0) /* get  value */
                 return MSG_ERR_MEM;
             argz_delete(&msg->azHeaders, &msg->asHeaders, cp);             /* del  value */
@@ -186,7 +194,7 @@ msg_rc_t msg_split(msg_t *msg)
             return MSG_ERR_MEM;
     }
     argz_add(&msg->azHeaders, &msg->asHeaders, "Path:");
-    argz_add(&msg->azHeaders, &msg->asHeaders, "not-for-mail"); //FIXME
+    argz_add(&msg->azHeaders, &msg->asHeaders, "not-for-mail"); /*FIXME */
 
     return MSG_OK;
 }
@@ -208,7 +216,7 @@ msg_rc_t msg_join(msg_t *msg)
     if (msg->azNewsgroups == NULL)
         return MSG_ERR_JOINGROUPNONE;
     argz_stringify(msg->azNewsgroups, msg->asNewsgroups, ',');
-    //fprintf(stderr, "DEBUG: join consolidated azNewsgroups = ***%s***\n", msg->azNewsgroups);
+    /*fprintf(stderr, "DEBUG: join consolidated azNewsgroups = ***%s***\n", msg->azNewsgroups); */
     if (strlen(msg->azNewsgroups) == 0)
         return MSG_ERR_JOINGROUPEMPTY;
     argz_add(&msg->azHeaders, &msg->asHeaders, "Newsgroups:");
@@ -253,7 +261,7 @@ msg_rc_t msg_join(msg_t *msg)
                 if (i < WRAPAT)
                     i++; /* we don't care about the whitespace itself */
                 cpCut = str_dup(cpRem, i);
-                //FIXME 1.) continue searching downwards skipping all whitespaces and 2.) as we know the length replace str_dup/ strcat/ free with strncat only
+                /*FIXME 1.) continue searching downwards skipping all whitespaces and 2.) as we know the length replace str_dup/ strcat/ free with strncat only */
                 if (cpWrap == NULL) {
                     if ((cpWrap = (char *)malloc(strlen(cpCut)+strlen(WRAPUSING)+1)) == NULL)
                         return MSG_ERR_MEM;
@@ -356,7 +364,7 @@ msg_rc_t msg_join(msg_t *msg)
     msg->cpMsg[n++] = '\n';
     msg->cpMsg[n]   = '\0';
 
-    //fprintf(stderr, "DEBUG: Message = ***%s***\n", msg->cpMsg);
+    /*fprintf(stderr, "DEBUG: Message = ***%s***\n", msg->cpMsg); */
     return MSG_OK;
 }
 
